@@ -156,7 +156,7 @@ XcupGetReservedColormapEntries(
 	}
 	_XRead (dpy, (char*) rbufp, nbytes);
 
-	*colors_out = (XColor*) Xmalloc (nentries  * sizeof (XColor));
+	*colors_out = Xcalloc (nentries, sizeof (XColor));
 	if (*colors_out) {
 	    xColorItem* cs = (xColorItem *) rbufp;
 	    XColor* cd = *colors_out;
@@ -170,12 +170,12 @@ XcupGetReservedColormapEntries(
 		cd->blue = cs->blue;
 		cs = (xColorItem*) (((char*) cs) + SIZEOF(xColorItem));
 	    }
-	    if (rbufp != rbuf) XFree ((char*) rbufp);
+	    if (rbufp != rbuf) XFree (rbufp);
 	    UnlockDisplay(dpy);
     	    SyncHandle();
 	    return True;
 	}
-	if (rbufp != rbuf) XFree ((char*) rbufp);
+	if (rbufp != rbuf) XFree (rbufp);
     }
     UnlockDisplay(dpy);
     SyncHandle();
@@ -251,7 +251,7 @@ XcupStoreColors(
 	    xcp->blue = cs->blue;
 	    xcp->flags = cs->flags;
 	}
-	if (rbufp != rbuf) XFree ((char*)rbufp);
+	if (rbufp != rbuf) XFree (rbufp);
 
 	UnlockDisplay(dpy);
 	SyncHandle();
